Managing a Camelot project — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot Documentation contents »
- Camelot Documentation »

# Managing a Camelot project

Release: | trunk
Date: | November 11, 2011

Once a project has been created and set up as described in the tutorial Creating a Movie Database Application, it needs to be maintained and managed over time.

See also

Schema Revisions and Migrations

Two tools exist to assist in the management of Camelot projects: camelot_admin.py and camelot_manage.py.

## camelot_admin.py

camelot_admin is a tool to assist in the creation and development of Camelot projects. Use this application without any options to start a GUI to create a new Camelot project.

`startproject`

  Starts a new project, use startproject project_name.

`makemessages`

  Outputs a message file with all field names of all entities. This command requires settings.py of the project to be in the PYTHONPATH

`apidoc`

  Extract API documentation from source code, to be used with sphinx.

`license_update`

  Change the license header of a project, use license_update project_directory license_file

`to_pyside`

  Takes a folder with PyQt4 source code and translates it to PySide source code. A directory to_pyside will be created containing the output of the translation

## camelot_manage.py

camelot_manage is oriented towards administrators of an installed camelot application. It is used for interacting the database, the model and migration of the database to a certain schema revision.

To use this application, PYTHONPATH should contain a valid settings.py file that will be used to resolve the database engine and the model.

`console`

  Launches a python console with the model all setup for command line interaction.

  Within the example movie project one could do the following to print a list of all movie titles to the screen:

      from model import Movie
      for movie in Movie.query.all():
      print movie.title

`db_version`

  Get the version of the database schema from the current database

`version`

  Get the latest available database schema version

`upgrade`

  Upgrade or downgrade the database to the specified version, use upgrade version_number.

`version_control`

  Put the database under version control

`schema_display`

  > Generate a graph of the database schema. The result is stored in schema.png. This option requires pydot to be installed.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot Documentation contents »
- Camelot Documentation »

Comments
blog comments powered by Disqus